@@ -1,4 +1,4 @@
-use crate::zfs;
+use crate::zfs_mount;
 use crate::yubi;
 use std::{io::Read, process::exit};
 use std::env;
@@ -16,7 +16,7 @@ pub fn pam_mode_yubi(base_dir: &String) {
         Ok(key) => key,
         Err(error) => panic!("{}", error),
     };
-    zfs::zfs_pam_mount(&key, base_dir.to_owned(), &user); // Unlock and mount ZFS Dataset
+    zfs_mount::zfs_pam_mount(&key, base_dir.to_owned(), &user); // Unlock and mount ZFS Dataset
 
     exit(0);
 }
@@ -38,7 +38,7 @@ pub fn pam_mode_file(base_dir: &String, file: &String) {
     let key = [file_hash,passhash].concat();
     let key = Sha512::digest(&key);
 
-    zfs::zfs_pam_mount(&format!("{:x}", &key), base_dir.clone(), &user); // Unlock and mount ZFS Dataset
+    zfs_mount::zfs_pam_mount(&format!("{:x}", &key), base_dir.clone(), &user); // Unlock and mount ZFS Dataset
 
     exit(0);
 }
\ No newline at end of file
